@@ -4,8 +4,8 @@ import sys
 
 import click
 
-from solarium.utils import update_color
 from . import led
+from .utils import update_color
 
 LOG_FORMAT = "%(asctime)s %(levelname)-8s %(message)s"
 
